# MSQMs: Magnetometers Quality Control Tool
MEG Signal Quality Metrics (MSQMs) is a fully automated quality control tool for OPM-MEG and SQUID-MEG.

[![PyPI - Version](https://img.shields.io/pypi/v/msqms?color)](https://badge.fury.io/msqms)
[![Documentation](https://readthedocs.org/projects/msqms/badge/?version=latest)](https://keras-complex.readthedocs.io/)
[![PyPI Versions](https://img.shields.io/pypi/pyversions/msqms.svg?color)](https://pypi.python.org/pypi/msqms?color=deepgreen)
[![PyPI License](https://img.shields.io/pypi/l/msqms.svg?color)](LICENSCE.md)
![PyPI - Downloads](https://img.shields.io/pypi/dm/msqms)


[//]: # ([![Build Status]&#40;https://travis-ci.org/JesperDramsch/msqms.svg?branch=master?color&#41;]&#40;https://travis-ci.org/JesperDramsch/msqms&#41;)
[//]: # ([![PyPI Status]&#40;https://img.shields.io/pypi/status/msqms.svg?color&#41;]&#40;https://pypi.python.org/pypi/msqms&#41;)

## Installation
```bash
pip install msqms
```

## Bug reports
Please use the [GitHub issue tracker](https://github.com/LiaoPan/msqms/issues) to report bugs.


## Interested in Contributing?
Please read our contributing guide.

## Citation
When using MSQMs, please include the following citation:


